@@ -239,7 +239,7 @@ try_tmpl_var_options (struct tmplpro_state *state, int tag_type, PSTRING* TagOpt
 	  try_tag_parameter(state, tagopt[i], TAGOPT[i])) {
 	TagOptVal[i] = read_tag_parameter_value(state);
 	found_in_loop=1;
-	if (debuglevel) log_state(state,TMPL_LOG_DEBUG,"in tag %s: found option %s\n", TAGNAME[tag_type], TAGOPT[i]);
+	if (debuglevel) log_state(state,TMPL_LOG_DEBUG,"in tag %s: found option %s=%.*s\n", TAGNAME[tag_type], TAGOPT[i],(int)(TagOptVal[i].endnext-TagOptVal[i].begin),TagOptVal[i].begin);
       }
     }
     if (!found_in_loop) opt_found = 0;
@@ -680,6 +680,32 @@ tmplpro_errmsg(struct tmplpro_param* param)
   return  errlist[param->htp_errno];
 }
 
+API_IMPL 
+int
+APICALL
+tmplpro_set_log_file(struct tmplpro_param* param, const char* logfilename)
+{
+  FILE *file_p;
+  if (NULL==logfilename) {
+    if (tmpl_log_stream!=NULL) {
+      fclose(tmpl_log_stream);
+      tmpl_log_stream=NULL;
+    }
+    tmpl_log_set_callback(tmpl_log_default_callback);
+    return 0;
+  }
+  file_p = fopen(logfilename, "w");
+  if (!file_p) {
+    tmpl_log(TMPL_LOG_ERROR,"tmplpro_set_log_file: can't create log file [%s]\n",logfilename);
+    return ERR_PRO_FILE_NOT_FOUND;
+  } else {
+    if (tmpl_log_stream!=NULL) fclose(tmpl_log_stream);
+    tmpl_log_stream=file_p;
+    tmpl_log_set_callback(tmpl_log_stream_callback);
+    return 0;
+  }
+}
+
 API_IMPL 
 size_t
 APICALL
